import propTypes from 'prop-types';
import React from 'react';
import { Text as RNText } from 'react-native';
import {
  colors,
  defaultSize,
  defaultVariant,
  Fonts,
} from '../../constant/theme';

const Text = ({
  text,
  size,
  variant,
  textStyle,
  children,
  color,
  ...props
}) => {
  return (
    <RNText
      {...props}
      style={[{ color: color }, Fonts[size], Fonts[variant], textStyle]}
    >
      {text}
      {children}
    </RNText>
  );
};

Text.propTypes = {
  children: propTypes.node,
  text: propTypes.oneOfType([propTypes.string, propTypes.number]),
  size: propTypes.oneOf(defaultSize),
  variant: propTypes.oneOf(defaultVariant),
  color: propTypes.string,
  textStyle: propTypes.oneOfType([propTypes.object, propTypes.array]),
};

Text.defaultProps = {
  size: 'medium',
  variant: 'regular',
  textStyle: {},
  children: null,
  color: colors.grey.black,
  text: '',
};

export default Text;
