import { Dimensions, PixelRatio, Platform } from 'react-native';

const widthPercentageToDP = (widthPercent) => {
  const screenWidth = Dimensions.get('window').width;
  // Convert string input to decimal number
  const elemWidth = parseFloat(widthPercent);
  return PixelRatio.roundToNearestPixel((screenWidth * elemWidth) / 100);
};
const heightPercentageToDP = (heightPercent) => {
  const screenHeight = Dimensions.get('window').height;
  // Convert string input to decimal number
  const elemHeight = parseFloat(heightPercent);
  return PixelRatio.roundToNearestPixel((screenHeight * elemHeight) / 100);
};
export { widthPercentageToDP, heightPercentageToDP };

export const defaultVariant = [
  'regular',
  'semibold',
  'bold',
  'italic',
  'light',
  'boldItalic',
];
export const defaultSize = [
  'superSmall',
  'extraSmall',
  'small',
  'medium',
  'large',
  'extraLarge',
  'superLarge',
  'Giant',
  'superGiant',
];
export const modalTypes = {
  CENTER: 'MODAL_CENTER',
  BOTTOM: 'MODAL_BOTTOM',
  TOP: 'MODAL_TOP',
};

export const colors = {
  primary: '#C33A2C',
  error: '#F55959',
  sec: {
    blue: '#5D8CF4',
    green: '#37B64F',
    green2: '#27AAB6',
    green3: '#71BF5C',
    magenta: '#C18EFF',
    purple: '#8D64C0',
    yellow: '#FDB813',
    orange: '#F7931D',
    red: '#DF5648',
  },
  grey: {
    black: '#000000',
    grey: '#757575',
    grey2: '#9B9B9B',
    grey3: '#C4C4C4',
    grey4: '#E5E5E5',
    grey5: '#F9F9F9',
    grey6: '#6A6A6A',
    grey7: '#CCCCCC',
    grey8: '#7A7A7A',
    white: '#FFFFFF',
    darkGrey: '#333333',
  },
  trans: {
    red: 'rgba(195, 58, 44, 0.1)',
  },
};

export const Fonts = {
  superSmall: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '1%' : Platform.OS === 'android' ? '1.4%' : '1.2%'
    ),
  },
  extraSmall: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '1.2%' : Platform.OS === 'android' ? '1.6%' : '1.4%'
    ),
  },
  middleSmall: {
    fontSize: heightPercentageToDP(Platform.isPad ? '1.4%' : '1.6%'),
  },
  small: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '1.4%' : Platform.OS === 'android' ? '1.8%' : '1.8%'
    ),
  },
  medium: {
    fontSize: heightPercentageToDP('2%'),
  },
  large: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '1.9%' : Platform.OS === 'android' ? '2.2%' : '2.2%'
    ),
  },
  extraLarge: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '2.1%' : Platform.OS === 'android' ? '2.5%' : '2.4%'
    ),
  },
  superLarge: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '2.4%' : Platform.OS === 'android' ? '2.7%' : '2.6%'
    ),
  },
  Giant: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '2.6%' : Platform.OS === 'android' ? '2.9%' : '2.8%'
    ),
  },
  superGiant: {
    fontSize: heightPercentageToDP(
      Platform.isPad ? '3.5%' : Platform.OS === 'android' ? '3.8%' : '3.7%'
    ),
  },
  regular: {
    fontFamily: 'Nunito-Regular',
  },
  bold: {
    fontFamily: 'Nunito-Bold',
  },
  boldItalic: {
    fontFamily: 'Nunito-BoldItalic',
  },
  italic: {
    fontFamily: 'Nunito-Italic',
  },
  semiBold: {
    fontFamily: 'Nunito-SemiBold',
  },
};
